#include <QtGui>
#include <QtCore>
#include "FileExplorer.h"
#include "screen_proxy/screen_proxy.h"

using namespace onyx::screen;

FileExplorer::FileExplorer(QWidget *parent)
    : QWidget(parent)
{
    this->setWindowTitle("File Explorer");
    QPushButton *quit = new QPushButton(tr("Quit"));
    QFont primaryfont("Arial", 14, 400, false);
    path.setFont(primaryfont);
    quit->setFont(primaryfont);

    dirList.setViewMode(QListView::ListMode);
    dirList.setResizeMode(QListWidget::Adjust);
    dirList.setUniformItemSizes(true);
    dirList.setIconSize(QSize(64, 64));
    dirList.setFont(primaryfont);

    dir.setPath("./");
    rehashDirectory();

    connect(&dirList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(cd(QListWidgetItem*)));
    connect(quit, SIGNAL(clicked()), qApp, SLOT(quit()));

    QVBoxLayout *layout = new QVBoxLayout;
    layout->addWidget(&path);
    layout->addWidget(&dirList);
    layout->addWidget(quit);
    setLayout(layout);
}

void FileExplorer::rehashDirectory(){
    dirList.clear();
    foreach(QFileInfo qfi, dir.entryInfoList(QDir::NoFilter, QDir::DirsFirst)){
        if(qfi.fileName() == ".") continue;
        QIcon icon(qfi.absoluteFilePath());
        QListWidgetItem *item = new QListWidgetItem(&dirList);
        item->setText(qfi.fileName());
        if (qfi.isDir()) item->setBackgroundColor(QColor(127, 127, 127));

        dirList.addItem(item);
    }

    path.setText(dir.absolutePath());
}

bool FileExplorer::event(QEvent* event)
{
    bool ret = QWidget::event(event);

    if (event->type() == QEvent::UpdateRequest)
    {
        refreshScreen(onyx::screen::GC);
        return true;
    }
    return ret;
}

void FileExplorer::refreshScreen(Waveform w){
    onyx::screen::ScreenProxy::instance().flush(this, w);
}

// Slots

void FileExplorer::cd(QListWidgetItem *itm){
    QFileInfo *file = new QFileInfo(dir.absoluteFilePath(itm->text()));
    if (file->isDir()) dir.cd(itm->text());
    rehashDirectory();
}
